/*
 * Copyright 2020 Esri
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.example.app

import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity

import android.util.Log
import android.widget.Toast
import com.esri.arcgisruntime.ArcGISRuntimeEnvironment
import com.esri.arcgisruntime.loadable.LoadStatus
import com.esri.arcgisruntime.mapping.MobileMapPackage
import com.esri.arcgisruntime.mapping.view.MapView

import com.example.app.databinding.ActivityMainBinding


class MainActivity : AppCompatActivity() {

    private val activityMainBinding by lazy {
      ActivityMainBinding.inflate(layoutInflater)
    }

    private val mapView: MapView by lazy {
      activityMainBinding.mapView
    }

    val TAG: String = MainActivity::class.java.simpleName

    private lateinit var mapPackage: MobileMapPackage


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setContentView(activityMainBinding.root)

        setApiKeyForApp()

        // access the mobile map package from the filesystem and load it into a MapView
        loadMobileMapPackage(getExternalFilesDir(null)?.path + getString(R.string.mahourivieratrails_mmpk))

    }

    override fun onPause() {
        mapView.pause()
        super.onPause()
    }

    override fun onResume() {
        super.onResume()
        mapView.resume()
    }

    override fun onDestroy() {
        mapView.dispose()
        super.onDestroy()
    }

    private fun setApiKeyForApp(){
        // set your API key
        // Note: it is not best practice to store API keys in source code. The API key is referenced
        // here for the convenience of this tutorial.

        ArcGISRuntimeEnvironment.setApiKey("YOUR_API_KEY")

    }

    // load your mobile map package here. You call this method from onCreate()
    private fun loadMobileMapPackage(mmpkFilePath: String) {

        // create the mobile map package
        mapPackage = MobileMapPackage(mmpkFilePath)
        // load the mobile map package
        mapPackage.loadAsync()

        // add done listener which will invoke when mobile map package has loaded
        mapPackage.addDoneLoadingListener() {
            // check load status and that the mobile map package has maps
            if (mapPackage.loadStatus === LoadStatus.LOADED && mapPackage.maps.isNotEmpty()) {
                // add the map from the mobile map package to the MapView
                mapView.map = mapPackage.maps[0]
            }

            else {
                // log an error if the mobile map package fails to load
                logError(mapPackage.loadError.message)
            }

        }

    } // end of loadMobileMapPackage()

    private fun logError(message: String?) {
        message?.let {
            Log.e(TAG, it)
            Toast.makeText(this, it, Toast.LENGTH_LONG).show()
        }
    }

}


